import { HSL, HSV, RGB8, RGBF, XYZ } from '../interfaces/color-models';
import { Lab } from '../index';
/**
 * Converter from 8 bit RGB colour model representation into other supported colour models.
 * sRGB colour space with D65 white point is assumed.
 */
export declare class FromRGB8 {
    /**
     * Converts RGB8 object to RGBF.
     * @param {RGB8} rgb
     * @returns {RGBF}
     */
    static toRGBF(rgb: RGB8): RGBF;
    /**
     * Converts RGB 8 bit values to RGBF.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {RGBF}
     */
    static toRGBF(r: number, g: number, b: number): RGBF;
    /**
     * Converts RGB8 object to HSL.
     * @param {RGB8} rgb
     * @returns {HSL}
     */
    static toHSL(rgb: RGB8): HSL;
    /**
     * Converts RGB 8 bit values to HSL.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {HSL}
     */
    static toHSL(r: number, g: number, b: number): HSL;
    /**
     * Converts RGB8 object to HSV.
     * @param {RGB8} rgb
     * @returns {HSV}
     */
    static toHSV(rgb: RGB8): HSV;
    /**
     * Converts RGB 8 bit values to HSV.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {HSV}
     */
    static toHSV(r: number, g: number, b: number): HSV;
    /**
     * Converts RGB8 object to XYZ.
     * @param {RGB8} rgb
     * @returns {XYZ}
     */
    static toXYZ(rgb: RGB8): XYZ;
    /**
     * Converts RGB 8 bit values to XYZ.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {XYZ}
     */
    static toXYZ(r: number, g: number, b: number): XYZ;
    /**
     * Converts RGB8 object to hexadecimal representation.
     * @param {RGB8} rgb
     * @returns {string}
     */
    static toHex(rgb: RGB8): string;
    /**
     * Converts RGB 8 bit values to hexadecimal representation.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {string}
     */
    static toHex(r: number, g: number, b: number): string;
    /**
     * Converts RGB8 object to hexadecimal representation with alpha component as the suffix.
     * @param {RGB8} rgb
     * @param {number} alpha
     * @returns {string}
     */
    static toRGBAHex(rgb: RGB8, alpha: number): string;
    /**
     * Converts RGB 8 bit values to hexadecimal representation with alpha component as the suffix.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @param {number} a
     * @returns {string}
     */
    static toRGBAHex(r: number, g: number, b: number, a: number): string;
    /**
     * Converts RGB8 object to hexadecimal representation with alpha component as the prefix.
     * @param {RGB8} rgb
     * @param {number} alpha
     * @returns {string}
     */
    static toARGBHex(rgb: RGB8, alpha: number): string;
    /**
     * Converts RGB 8 bit values to hexadecimal representation with alpha component as the prefix.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @param {number} a
     * @returns {string}
     */
    static toARGBHex(r: number, g: number, b: number, a: number): string;
    /**
     * Converts RGB8 object to CSS RGB notation.
     * @param {RGB8} rgb
     * @returns {string}
     */
    static toCssRgb(rgb: RGB8): string;
    /**
     * Converts RGB 8 bit values to CSS RGB notation.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {string}
     */
    static toCssRgb(r: number, g: number, b: number): string;
    /**
     * Converts RGB8 object to CSS RGBA notation.
     * @param {RGB8} rgb
     * @param {number} alpha
     * @returns {string}
     */
    static toCssRgba(rgb: RGB8, alpha: number): string;
    /**
     * Converts RGB 8 bit values to CSS RGBA notation.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @param {number} alpha
     * @returns {string}
     */
    static toCssRgba(r: number, g: number, b: number, alpha: number): string;
    /**
     * Converts RGB8 object to Lab.
     * @param {RGB8} rgb
     * @returns {Lab}
     */
    static toLab(rgb: RGBF): Lab;
    /**
     * Converts RGB8 values to Lab.
     * @param {number} r
     * @param {number} g
     * @param {number} b
     * @returns {Lab}
     */
    static toLab(r: number, g: number, b: number): Lab;
    private static resolveArguments(r, g?, b?);
    private static resolveRGBAArguments(r, g, b?, a?);
}
